import { ContractTypeDefinitions, defineContractExport, defineContracts } from "@dunemask/vix/util";
import * as y from "yup";
import { DatabaseContractRes } from "./database.contracts";

// ======================================= Re-used Contracts -======================================

const Credentials = y.object({
  user: DatabaseContractRes.User.required(),
  policies: y.array(y.string()).required(),
});

// ====================================== Responses Contracts ======================================

export const AuthContractRes = defineContractExport("CAuthContractRes", {
  Credentials,
  LoginCredentials: y
    .object({
      token: y.string().required(),
    })
    .concat(Credentials),
});

// ======================================= Request Contracts =======================================

export const AuthContractReq = defineContractExport("CAuthContractReq", {
  Login: y.object({
    identity: y.string().required(),
    password: y.string().required(),
  }),
});

// ===================================== Combined Declarations =====================================

export const AuthContract = defineContractExport("CAuthContract", { ...AuthContractRes, ...AuthContractReq });

// ======================================= Type Declarations =======================================

export type CAuthContractRes = ContractTypeDefinitions<typeof AuthContractRes>;
export type CAuthContractReq = ContractTypeDefinitions<typeof AuthContractReq>;
export type CAuthContract = ContractTypeDefinitions<typeof AuthContract>;
