import { ContractTypeDefinitions, defineContractExport, defineContracts } from "@dunemask/vix/util";
import { KeyPairType } from "@prisma/client";
import * as y from "yup";
const antiRequired = y.string().test("insecure-exposure", "Insecure Exposure", (value) => !!value);
// ====================================== Reused Contracts ======================================

// ====================================== Response Contracts ======================================

export const KeyPairContractRes = defineContractExport("CKeyPairContractRes", {});

// ====================================== Request Contracts ======================================

export const KeyPairContractReq = defineContractExport("CKeyPairContractReq", {
  Create: y.object({
    projectId: y.string().required(),
    usage: y.string().oneOf(Object.values(KeyPairType)).required(),
    encryptedPublicKey: y.string().required(),
    encryptedPrivateKey: y.string().required(),
    name: y.string().nullable(),
  }),
});

// ====================================== Combined Declarations ======================================

export const KeyPairContract = defineContractExport("CKeyPairContract", { ...KeyPairContractRes, ...KeyPairContractReq });

// ====================================== Type Declarations ======================================

export type CKeyPairContractRes = ContractTypeDefinitions<typeof KeyPairContractRes>;
export type CKeyPairContractReq = ContractTypeDefinitions<typeof KeyPairContractReq>;
export type CKeyPairContract = ContractTypeDefinitions<typeof KeyPairContract>;
