import { Icon, IconButton, IconButtonProps, Input, InputGroup, InputProps, InputRightElement } from "@chakra-ui/react";
import { SyntheticEvent, useEffect, useState } from "react";
import { FaEye, FaEyeSlash } from "react-icons/fa";

interface PasswordInputProps extends InputProps {
  value: string;
  setPassword: (password: string) => void;
  InputProps?: InputProps;
  IconButtonProps?: IconButtonProps;
}

export function PasswordInput(props: PasswordInputProps) {
  const { setPassword, value } = props;
  const [visible, setVisible] = useState<boolean>();
  const toggleVisible = () => setVisible(!visible);

  const inputType = visible ? "text" : "password";
  const inputIcon = visible ? FaEyeSlash : FaEye;
  const passwordChange = (e: SyntheticEvent) => setPassword((e.target as HTMLInputElement).value);
  const iconButtonProps: IconButtonProps = { ...props.IconButtonProps, "aria-label": "Show Password" };

  const combinedInputProps: InputProps = { ...props.InputProps, value, onChange: passwordChange };

  return (
    <InputGroup>
      <Input placeholder="Password" type={inputType} onChange={passwordChange} {...combinedInputProps} />
      <InputRightElement>
        <IconButton _hover={{ bg: "inherit", opacity: ".8" }} onClick={toggleVisible} {...iconButtonProps}>
          <Icon as={inputIcon} />
        </IconButton>
      </InputRightElement>
    </InputGroup>
  );
}
