import { Policy } from "@lib/Policies";
import { useAuth } from "@src/ctx/AuthContext";
import { ReactNode } from "react";

export enum GUARD_TARGETS {
  ACTIVE = "active",
  SPOOF = "spoof",
  USER = "user",
}

interface GuardedContentProps {
  guard: Policy[] | boolean;
  children: ReactNode | ReactNode[];
  target?: GUARD_TARGETS;
}

export function useGuardTarget(target = GUARD_TARGETS.ACTIVE) {
  const { activePolicies, userPolicies, spoofPolicies } = useAuth();
  const policyMapping = {
    [GUARD_TARGETS.ACTIVE]: activePolicies,
    [GUARD_TARGETS.SPOOF]: spoofPolicies,
    [GUARD_TARGETS.USER]: userPolicies,
  };
  return policyMapping[target];
}

export default function useContentGuard(required: Policy[], target = GUARD_TARGETS.ACTIVE) {
  const policies = useGuardTarget(target);
  return Policy.multiAuthorizedTo(policies, required);
}

export function GuardedContent(props: GuardedContentProps) {
  const guardTarget = props.target ?? GUARD_TARGETS.ACTIVE;
  const policies = useGuardTarget(guardTarget);
  if (props.guard === false) return undefined;
  if (props.guard === true) return props.children;
  if (Policy.multiAuthorizedTo(policies, props.guard)) return props.children;
  return undefined;
}
