import { useNavigate } from "react-router-dom";

export enum StaticLinks {
  Authenticate = "/authenticate",
  AutoRedirect = "/auto-redirect",
  ProjectView = "/projects",
  Settings = "/settings",
  Authorized = "/authorized",
}

export enum DynamicLinks {}

type LinkEnums<T extends Record<string, string>> = T[keyof T];
export const Links = { ...StaticLinks, ...DynamicLinks };
export type Links = LinkEnums<typeof Links>;
export const rootLink = (l: Links) => import.meta.env.BASE_URL + l.substring(1);
export function useLinkNav() {
  const nav = useNavigate();
  const linkNav = (l: Links) => nav(rootLink(l));
  return linkNav;
}

export function useAutoRedirect() {
  const search = window.location.search;
  const nav = useNavigate();
  const redirectLink = `${rootLink(Links.AutoRedirect)}${search}`;
  return () => nav(redirectLink);
}
