import { extendTheme, ThemeConfig } from "@chakra-ui/react";

const themeConfig: ThemeConfig = {
  initialColorMode: "dark",
  useSystemColorMode: false,
};

const theme = extendTheme({
  config: themeConfig,
  colors: {
    primary: {
      "50": "#fef7e8",
      "100": "#fadda3",
      "200": "#f5bc4c",
      "300": "#d99a1d",
      "400": "#c28a1a",
      "500": "#f3ac20",
      "600": "#8a6212",
      "700": "#6f4f0f",
      "800": "#5e420c",
      "900": "#443009",
    },
    secondary: "#ffbc03",
    background: {
      default: "#101010",
      paper: "#222222",
    },
  },
  fonts: {
    heading: "Inter, sans-serif",
    body: "Inter, sans-serif",
  },
  fontSizes: {
    "4xl": "4rem",
    "3xl": "3rem",
    "2xl": "2rem",
    xl: "1.5rem",
    lg: "1.2rem",
    md: "1rem",
  },
  components: {
    Modal: {
      baseStyle: {
        dialog: {
          borderRadius: "18px",
        },
        closeButton: {
          borderRadius: "full",
          bg: "primary",
          _hover: {
            bg: "secondary",
          },
        },
      },
    },
    Button: {
      baseStyle: {
        textTransform: "none",
        fontWeight: "bold",
      },
      sizes: {
        md: {
          borderRadius: "8px",
        },
      },
      variants: {
        solid: (props: { colorMode: string }) => ({
          bg: props.colorMode === "dark" ? "primary" : "secondary",
          color: "white",
          _hover: {
            bg: props.colorMode === "dark" ? "secondary" : "primary",
          },
        }),
      },
    },
  },
  styles: {
    global: (props: { colorMode: string }) => ({
      body: {
        bg: props.colorMode === "dark" ? "#1c1c1c" : "#eee", // Adjust based on colorMode
      },
    }),
  },
});

export default theme;
