import { Center, Flex, Spinner, Text } from "@chakra-ui/react";
import AppGuard from "@lib/Guards";
import { useAuth } from "@src/ctx/AuthContext";
import useContentGuard, { GuardedContent } from "@src/util/guards";
import { Links, rootLink } from "@src/util/links";
import { useEffect, useState } from "react";
import { Navigate, useSearchParams } from "react-router-dom";

const { search } = window.location;
const redirectLink = (l: Links) => `${rootLink(l)}${search}`;

export default function AutoRedirect() {
  const manageProjects = useContentGuard(AppGuard.ManageProjects);
  const [serachParams] = useSearchParams();
  const redirectUri = serachParams.get("redirectUri");

  const { auth, initialized, loading } = useAuth();
  if (!initialized || loading) return <RedirectLoader />;
  if (!!redirectUri) return <RedirectPortal />;
  if (!auth) return <Navigate to={redirectLink(Links.Authenticate)} />;
  if (manageProjects) return <Navigate to={redirectLink(Links.ProjectView)} />;
  return <Navigate to={redirectLink(Links.Authorized)} />;
}

export function RedirectLoader() {
  const [visible, setVisible] = useState<boolean>(false);
  useEffect(() => {
    setTimeout(() => setVisible(true), 1500);
  }, []);
  return (
    <Center m="auto" h="100vh">
      <Flex flexWrap="wrap">
        <GuardedContent guard={visible}>
          <Spinner size="xl" color="primary" m="auto" />
          <Text w="100%" textAlign="center" mt="1.5rem">
            Loading
          </Text>
        </GuardedContent>
      </Flex>
    </Center>
  );
}

export function RedirectPortal() {
  const { auth, token } = useAuth();
  const [search] = useSearchParams();
  const redirectUri = search.get("redirectUri");
  useEffect(() => {
    if (!auth || !redirectUri || !token) return;
    window.location.href = `${redirectUri}?cairoUserToken=${token}`;
  }, [auth, redirectUri, token]);

  if (!auth) return <Navigate to={redirectLink(Links.Authenticate)} />;

  return (
    <Flex h="100vh" w="100%">
      <Center w="100%">
        <Flex flexWrap="wrap" textAlign="center">
          <Text w="100%" fontSize="16px">
            Your request has been authorized!
          </Text>
          <Text w="100%" fontSize="13px">
            You will be automatically redirected within a few seconds
          </Text>
        </Flex>
      </Center>
    </Flex>
  );
}
